@@ -248,9 +248,11 @@ func (c *StackCollection) UpdateStack(options UpdateStackOptions) error {
 			return err
 		}
 		options.Stack = s
+	} else {
+		options.StackName = *options.Stack.StackName
 	}
 	if err := c.doCreateChangeSetRequest(
-		*options.Stack.StackName,
+		options.StackName,
 		options.ChangeSetName,
 		options.Description,
 		options.TemplateData,
