@@ -86,23 +86,6 @@ func isNonEKSCluster(cluster *awseks.Cluster) bool {
 
 // ClusterSupportsManagedNodes reports whether the EKS cluster supports managed nodes
 func ClusterSupportsManagedNodes(cluster *awseks.Cluster) (bool, error) {
-	supportsManagedNodes, err := utils.IsMinVersion(api.Version1_15, *cluster.Version)
-	if err != nil {
-		return false, err
-	}
-	if supportsManagedNodes {
-		return true, nil
-	}
-
-	versionSupportsManagedNodes, err := VersionSupportsManagedNodes(*cluster.Version)
-	if err != nil {
-		return false, err
-	}
-
-	if !versionSupportsManagedNodes {
-		return false, nil
-	}
-
 	if cluster.PlatformVersion == nil {
 		logger.Warning("could not find cluster's platform version")
 		return false, nil
